Article View: borland.public.cppbuilder.nativeapi
Article #6618Re: Weird optimisation results
From: Andrue Cope [TeamB]
Date: Thu, 28 Apr 2005 09:30
Date: Thu, 28 Apr 2005 09:30
16 lines
1306 bytes
1306 bytes
Andrue Cope [TeamB] wrote: > It doesn't. In fact it gives a performance hit. On my standard NTFS > test image the old code averages 38 seconds over ten runs. The new > code averages 34 seconds over ten runs. Oops. That was a typo. It's the other way around. So replacing the for() loop with a reinterpret_cast causes something around a 10% performance hit. Apparently. :-/ -- Andrue Cope [TeamB] [Bicester, Uk] http://info.borland.com/newsgroups/guide.html
Technical Details
Message-ID:
<4270ad23$1@newsgroups.borland.com>Path:
arc1-ca.pugleaf.net!g2news1.google.com!news3.google.com!news.glorb.com!newsfeed00.sul.t-online.de!newsfeed01.sul.t-online.de!t-online.de!newsgroups.borland.com!not-for-mailReferences:
<4270aa35$1@newsgroups.borland.com>Show Full Headers
Complete Article Headers
X-Google-Thread: 10cc67,558eed2a222ed4da X-Google-Attributes: gid10cc67,public X-Google-Language: ENGLISH,ASCII-7-bit From: "Andrue Cope [TeamB]" <no.spam@not.a.valid.address> Subject: Re: Weird optimisation results Newsgroups: borland.public.cppbuilder.nativeapi References: <4270aa35$1@newsgroups.borland.com> Date: Thu, 28 Apr 2005 10:30:45 +0100 User-Agent: XanaNews/1.17.4.1 MIME-Version: 1.0 Content-Type: text/plain; charset=iso-8859-1 NNTP-Posting-Host: 217.207.223.34 Message-ID: <4270ad23$1@newsgroups.borland.com> X-Trace: newsgroups.borland.com 1114680611 217.207.223.34 (28 Apr 2005 02:30:11 -0700) Lines: 16 X-Authenticated-User: acope Path: arc1-ca.pugleaf.net!g2news1.google.com!news3.google.com!news.glorb.com!newsfeed00.sul.t-online.de!newsfeed01.sul.t-online.de!t-online.de!newsgroups.borland.com!not-for-mail